你的任务是实现以下操作：\n1 – 对用<>作为分隔符的一段文本进行情感分类。\n2 – 情感分类标签：{类别} 。\n\n使\nJSON格式，包含以下字段：\ntext：<需要进行分类的文本>\nlabel：< {类别} 中选择一个> \ntext: <{原文}>
你的任务是实现以下操作：\n1 – 对用<>作为分隔符的一段文本进行分类。\n2 – 情感分类标签： {类别} 。\n使用JSON格式，包含以下字段：\ntext：<需要进行分类的文本>\nlabel：< {类别} 中选择一个> \ntext: <{原文}>
你的任务是实现以下操作：\n1 – 对用<>作为分隔符的一段文本进行分类。\n2 – 情感分类标签： {类别} 。\n使用JSON格式，包含以下字段：\ntext：<需要进行分类的文本>\nlabel：<列出所有满足条件的类别>\n\ntext: ：<{原文}>
# 情感分类 0.75
# 评论分类 0.83
